Index: debian/postinst
===================================================================
--- debian/postinst	(Revision 38475)
+++ debian/postinst	(Arbeitskopie)
@@ -97,16 +97,22 @@
 [ "$boot_devfs" ] || boot_devfs="$root_devfs"
 boot="$(mapdevfs "$boot_devfs")"
 info "boot partition: $boot"
+# the partition where quik is installed must be ext2 and quik must be installed on the first disk
 if [ "$boot_devfs" != "$root_devfs" ]; then
-    # TODO: Is this still required, now that we put kernel symlinks in
-    # /boot?
-    die quik-installer/boot_not_on_root '/boot not on /'
+    if ! grep '[[:space:]]/target/boot[[:space:]]ext2[[:space:]]' /proc/mounts \
+        >/dev/null; then
+        # TODO: this message does not yet exist
+        die quik-installer/boot_not_ext2 '/boot not ext2'
+    fi
+    if [ "${boot#/dev/hd}" != "$boot" ] && [ "${boot#/dev/hda}" = "$boot" ]; then
+        # TODO: this message does not yet exist
+        die quik-installer/boot_not_on_first_disk '/boot not on first disk'
+    fi
+    elif ! grep '[[:space:]]/target[[:space:]]ext2[[:space:]]' /proc/mounts \
+        >/dev/null; then
+        die quik-installer/root_not_ext2 '/ not ext2'
 fi
 
-if ! grep '[[:space:]]/target[[:space:]]ext2[[:space:]]' /proc/mounts \
-   >/dev/null; then
-    die quik-installer/root_not_ext2 '/ not ext2'
-fi
 
 # Generate quik.conf
 
@@ -146,10 +152,21 @@
     realinitrd="${initrd%/*}/$realinitrd"
 fi
 
-rm -f /target/etc/quik.conf
+if [ "$boot_devfs" != "$root_devfs" ]; then
+	quikconf=/target/boot/etc/quik.conf
+	mkdir -p /target/boot/etc
+	quikinstall="quik -v -f -C /boot/etc/quik.conf"
+else 
+	quikconf=/target/etc/quik.conf
+	quikinstall="quik -v -f"
 
+fi
+
+#TODO: in case /boot is a seperate partition: make a link from /etc/quik.conf to /boot/etc/quik.conf
+rm -f $quikconf
+
 writequikconf() {
-    writefile /target/etc/quik.conf quik.conf
+    writefile $quikconf quik.conf
 }
 
 writequikconf <<EOF
@@ -161,6 +178,8 @@
 root=$root
 partition=$partnr
 
+#	TODO: AFAIK this comment isnt true anymore and should be removed..
+#		this needs confirmation/testing
 ## Do not point image= to a symlink, quik can't follow symlinks
 image=$realkernel
 	label=Linux
@@ -199,7 +218,7 @@
 db_get "$WARNING_TEMPLATE"
 [ "$RET" = true ] || exit 10
 
-log-output -t quik-installer chroot /target quik -v -f || \
+log-output -t quik-installer chroot /target $quikinstall || \
     die quik-installer/quikerr "quik failed with exit status $?"
 
 # Configure OpenFirmware (OldWorld only)
Index: debian/changelog
===================================================================
--- debian/changelog	(Revision 38475)
+++ debian/changelog	(Arbeitskopie)
@@ -1,3 +1,15 @@
+quik-installer (0.0.14) unstable; urgency=low
+
+  [Holger Levsen]
+  * adjusted the partition checks to match with current quik version (Closes: #321820)
+  * if /boot is a seperate partition, quik.conf needs to reside in
+    /boot/etc/quik.conf
+  * TODO: to new strings, not yet in po: 
+  	quik-installer/boot_not_ext2 '/boot not ext2'
+        quik-installer/boot_not_on_first_disk '/boot not on first disk'
+
+ -- Holger Levsen <debian@layer-acht.org>  Thu, 29 Jun 2006 18:40:30 +0200
+
 quik-installer (0.0.13) unstable; urgency=low
 
   [ Joey Hess ]
